@@ -3,8 +3,8 @@ import os
 
 
 def get_default_data():
-    sampleloc = os.path.dirname(__file__) + '\samples'
-    with open(sampleloc + '\sample_input.json') as json_user_data_file:
+    sampleloc = os.path.dirname(__file__) + '/samples'
+    with open(sampleloc + '/sample_input.json') as json_user_data_file:
         return json.load(json_user_data_file)
 
 
