@@ -1,5 +1,5 @@
 import os
-import xml
+import xml.dom.minidom
 
 mapping_common_to_SAS = {}
 
@@ -7,7 +7,10 @@ mapping_common_to_SAS = {}
 def get_mappings_in_out(
         in_enrichname='biocatch_getscore', in_file_name='biocatch_getscore_payload.xml', in_subtype='getScore',
         out_enrichname='biocatch_out', out_file_name='biocatch_to_sas.xml', out_mapperId='biocatchRespToOde',
-        basedir='../src/enrich_pkg/xml/'):
+        basedir=None):
+
+    if basedir is None:
+        basedir = os.path.dirname(__file__) + '/xml/'
 
     if (in_subtype not in get_mapping(in_file_name, basedir)):
         print('stop here!')
@@ -85,7 +88,7 @@ def read_to_sas_mappings(infile, basedir):
 
     return source_to_target
 
-def Read_default_mappings(infile, isCommonMapping):
+def read_default_mappings(infile, isCommonMapping):
     global mapping_common_to_SAS
 
     source_to_target = {}
@@ -121,17 +124,17 @@ def Read_default_mappings(infile, isCommonMapping):
 
 
 def entry():
-    xmldir = os.path.dirname(__file__) + '/xml'
-    return get_mapping('f', xmldir)
+    xmldir = os.path.dirname(__file__) + '/xml/'
+    return get_mapping('biocatch_getscore_payload.xml', xmldir)
 
 
-def get_mapping (whichFile, xmldir='./enrich_pkg/xml/', includeSAS=False):
+def get_mapping (whichFile, xmldir, includeSAS=False):
     global mapping_common_to_SAS
 
     if len(mapping_common_to_SAS.keys()) == 0:
-        mapping_common_to_SAS = Read_default_mappings(xmldir + 'common_to_sas.xml', True)
+        mapping_common_to_SAS = read_default_mappings(xmldir + 'common_to_sas.xml', True)
 
-    return Read_default_mappings(xmldir + whichFile, includeSAS)
+    return read_default_mappings(xmldir + whichFile, includeSAS)
 
 
 def get_payfoneverify_mappings():
